@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from PyQt4 import QtCore, QtGui
-from . import base_ui_window_class
+from . import base_ui_window_class, base_listview_class
 
 class Ui_winFeedList(base_ui_window_class):
         
@@ -10,7 +10,7 @@ class Ui_winFeedList(base_ui_window_class):
         self.win.move(0, 0)
     
     def add_widgets(self):
-        self.listFeedList = QtGui.QListView(self.centralWidget)
+        self.listFeedList = base_listview_class(self.centralWidget)
         self.listFeedList.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
         self.listFeedList.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
         self.listFeedList.setProperty("showDropIndicator", False)
